﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.AccessCache;
using Windows.Storage.Pickers;
using Windows.UI;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using QtsHttp;
using QtsHttp.Comm;
using QtsHttp.FileStaion;
using System.Net.Http;
using System.Net;
using System.Threading.Tasks;
// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace SampleStoreHttp
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        App app = Application.Current as App;
        private Server _qtsServer = null;
        public IQtsHttpFileStation _fsObj = null;

        public MainPage()
        {
            NavigationCacheMode = Windows.UI.Xaml.Navigation.NavigationCacheMode.Enabled;
            this.Loaded += MainPage_Loaded;
            this.InitializeComponent();
            if (app.gFSObj != null)
            {
                logoutButton.IsEnabled = true;
                loginButton.IsEnabled = false;
            }
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {

        }

        private void WatermarkTBGotFocus(object sender, RoutedEventArgs e)
        {
            if (hostName.Text == "255.255.255.255")
            {
                SolidColorBrush Brush1 = new SolidColorBrush();
                Brush1.Color = Colors.Black;
                
                hostName.Text = "";
                hostName.Foreground = Brush1;

                port.Text = "";
                port.Foreground = Brush1;

                userName.Text = "";
                userName.Foreground = Brush1;

                password.Password = "";
                password.Foreground = Brush1;

            }
        }

        private void WatermarkTBLostFocus(object sender, RoutedEventArgs e)
        {
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }

        private async void ButtonClickLogin(object sender, RoutedEventArgs e)
        {
            var messageDialog = new MessageDialog("");

            if (hostName.Text == "" || IsIPv4(hostName.Text) == false)
            {
                messageDialog.Content = "Invalid Host Name!";
                await messageDialog.ShowAsync();
                return;
            }
            if (userName.Text == string.Empty)
            {
                messageDialog.Content = "Please input User Name!";
                await messageDialog.ShowAsync();
                return;
            }
            if (password.Password == string.Empty)
            {
                messageDialog.Content = "Please input Password!";
                await messageDialog.ShowAsync();
                return;
            }

            string serHostName = hostName.Text;
            string serUserName = userName.Text;
            string serPassword = password.Password;
            string strComputerName = string.Empty;
            long serPort = Convert.ToInt64(port.Text);

            ServerInfo serverInfo = new ServerInfo(serHostName, serUserName, serPassword, false, strComputerName);
            _qtsServer = new Server(serverInfo);
            _qtsServer.SetFileStationPortNum(Convert.ToInt64(port.Text));
            try
            {
                await _qtsServer.Login(StationType.FileStation);

                if (_qtsServer.QueryFileStationVersion() == APIVersion.FileStationApiV1)
                {
                    _fsObj = _qtsServer.OpenFileStation();
                    logoutButton.IsEnabled = true;
                    loginButton.IsEnabled = false;
                    app.gFSObj = _fsObj;
                    this.Frame.Navigate(typeof(Page_Function));
                }
            }
            catch (Exception ex)
            {
                messageDialog.Content = "Login Failed " + ex.Message;
                messageDialog.ShowAsync();
            }

        }

        private async void ButtonClickLogout(object sender, RoutedEventArgs e)
        {
            APIResult logoutResult = APIResult.Failure;
            var messageDialog = new MessageDialog("");

            if (app.gFSObj == null)
            {
                messageDialog.Content = "Please Login before Logout.";
                await messageDialog.ShowAsync();
                return;
            }
            else
            {
                try
                {
                    await _qtsServer.CloseFileStation(app.gFSObj);

                    logoutButton.IsEnabled = false;
                    loginButton.IsEnabled = true;
                }
                catch (Exception ex)
                {
                    messageDialog.Content = "Logout Failed " + ex.Message;
                    messageDialog.ShowAsync();
                }
            }
        }

        public bool IsIPv4(string value)
        {
            var quads = value.Split('.');

            // if we do not have 4 quads, return false
            if (!(quads.Length == 4)) return false;

            // for each quad
            foreach (var quad in quads)
            {
                int q;
                // if parse fails 
                // or length of parsed int != length of quad string (i.e.; '1' vs '001')
                // or parsed int < 0
                // or parsed int > 255
                // return false
                if (!Int32.TryParse(quad, out q)
                    || !q.ToString().Length.Equals(quad.Length)
                    || q < 0
                    || q > 255) { return false; }
            }

            return true;
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            app.gFSObj = _fsObj;
            base.OnNavigatedFrom(e);
        }
    }
}
