﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using QtsHttp.Comm;
using QtsHttp.FileStaion;
// The Basic Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234237

namespace SampleStoreHttp
{
    /// <summary>
    /// A basic page that provides characteristics common to most applications.
    /// </summary>
    public sealed partial class Page_Download : SampleStoreHttp.Common.LayoutAwarePage
    {
        App app = Application.Current as App;
        MessageDialog messageDialog = new MessageDialog("");
        CancellationTokenSource reqCancel = new CancellationTokenSource();
        StorageFolder destFolder = null;
        public Page_Download()
        {
            NavigationCacheMode = Windows.UI.Xaml.Navigation.NavigationCacheMode.Enabled;
            this.InitializeComponent();
        }

        private async void Button_Click_SelectLocalFolder(object sender, RoutedEventArgs e)
        {
            FolderPicker folderPicker = new FolderPicker();
            folderPicker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            folderPicker.FileTypeFilter.Add(".");
            folderPicker.ViewMode = PickerViewMode.Thumbnail;
            StorageFolder folder = await folderPicker.PickSingleFolderAsync();

            //var testfolder = KnownFolders.PicturesLibrary;
            //var files = await folder.GetFilesAsync();

            if (folder != null)
            {
                destFolder = folder;
                if (folder.Path != string.Empty)
                    destPath.Text = folder.Path;
                else
                    destPath.Text = folder.DisplayName;

                if (srcPath.Text != string.Empty)
                    downloadButton.IsEnabled = true;
            }
        }

        private async void Button_Click_Download(object sender, RoutedEventArgs e)
        {
            SyncProgressCallback progress = new SyncProgressCallback(DownloadUpload_Progress);
            Stream returnStream = null;
            try
            {
                returnStream = await app.gFSObj.DownloadFileByPath(srcPath.Text, "", 0, this, progress, reqCancel);
            }
            catch (Exception ex)
            {
                messageDialog.Content = ex.Message;
                messageDialog.ShowAsync();
            }

            if (returnStream != null)
            {
                FileStatus returnFileStatus = new FileStatus();
                returnFileStatus = await app.gFSObj.GetFileStatus(srcPath.Text, reqCancel);
                ulong downloadFileSize = (ulong)returnFileStatus.FileSize;

                string srcFilePath = srcPath.Text;
                int lastSlash = srcFilePath.LastIndexOf("/");
                string splitFolderPath = srcFilePath.Substring(0, lastSlash);
                string splitFileName = srcFilePath.Substring(lastSlash + 1, (srcFilePath.Length - splitFolderPath.Length) - 1);
                //StorageFolder x = await StorageFolder.GetFolderFromPathAsync("\\Music");
                StorageFile localDownloadFile = await destFolder.CreateFileAsync(splitFileName, CreationCollisionOption.GenerateUniqueName);
                
                int ncount = 0;
                ulong totalsize = 0;
                byte[] buffer = new byte[5242880];
                int nprogress = 0;

                while ((ncount = await returnStream.ReadAsync(buffer, 0, buffer.Length)) > 0)
                {
                    using (Stream f = await localDownloadFile.OpenStreamForWriteAsync())
                    {
                        f.Seek(0, SeekOrigin.End);
                        await f.WriteAsync(buffer, 0, ncount);
                        totalsize += (ulong)ncount;
                        nprogress = (int)(totalsize * 100 / downloadFileSize);
                        progress(this, nprogress);
                    }
                }
            }
        }

        private async void DownloadUpload_Progress(object sender, int nProgress)
        {
            System.Diagnostics.Debug.WriteLine("progress: " + nProgress);
            DownloadProgress.Value = nProgress;
            if (nProgress == 100)
            {
                messageDialog.Content = "Download Complete!";
                await messageDialog.ShowAsync();
                DownloadProgress.Visibility = Visibility.Collapsed;
                DownloadProgress.Value = 0;
                DownloadProgress.Visibility = Visibility.Visible;
            }
        }
    }
}
