﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using QtsHttp.Comm;
using QtsHttp.FileStaion;
// The Basic Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234237

namespace SampleStoreHttp
{
    /// <summary>
    /// A basic page that provides characteristics common to most applications.
    /// </summary>
    public sealed partial class Page_Upload : SampleStoreHttp.Common.LayoutAwarePage
    {
        App app = Application.Current as App;
        MessageDialog messageDialog = new MessageDialog("");
        CancellationTokenSource reqCancel = new CancellationTokenSource();
        StorageFile localFile = null;
        long uploadFileSize = 0;

        public Page_Upload()
        {
            NavigationCacheMode = Windows.UI.Xaml.Navigation.NavigationCacheMode.Enabled;
            this.InitializeComponent();
        }

        private async void Button_Click_SelectLocalFile(object sender, RoutedEventArgs e)
        {
            FileOpenPicker openPicker = new FileOpenPicker();
            openPicker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            openPicker.FileTypeFilter.Add("*");
            StorageFile file = await openPicker.PickSingleFileAsync();
            if (file != null)
            {
                localFile = file;
                if (file.Path != string.Empty)
                    srcPath.Text = file.Path;
                else
                    srcPath.Text = file.DisplayName;

                if (destPath.Text != string.Empty)
                    uploadButton.IsEnabled = true;
            }
        }

        private async void Button_Click_Upload(object sender, RoutedEventArgs e)
        {
            IRandomAccessStream localFileStream = await localFile.OpenAsync(FileAccessMode.Read);
            uploadFileSize = (long)localFileStream.Size;
            SyncProgressBtyesCallback progress = new SyncProgressBtyesCallback(DownloadUpload_Progress);
            string srcFilePath = srcPath.Text;
            int lastSlash = srcFilePath.LastIndexOf("\\");
            string splitFolderPath = srcFilePath.Substring(0, lastSlash);
            string splitFileName = srcFilePath.Substring(lastSlash + 1, (srcFilePath.Length - splitFolderPath.Length) - 1);

            
            try
            {
                await app.gFSObj.UploadFileByPath(splitFileName, destPath.Text, this, localFileStream.AsStreamForRead(), progress, reqCancel);
            }
            catch (Exception ex)
            {
                messageDialog.Content = ex.Message;
                messageDialog.ShowAsync();
            }

        }

        private async void DownloadUpload_Progress(object sender, long totalbytes)
        {
            int nProgress = (int)(totalbytes * 100 / uploadFileSize);
            System.Diagnostics.Debug.WriteLine("progress: " + nProgress);
            UploadProgress.Value = nProgress;
            if (nProgress == 100)
            {
                messageDialog.Content = "Upload Complete!";
                await messageDialog.ShowAsync();
                UploadProgress.Visibility = Visibility.Collapsed;
                UploadProgress.Value = 0;
                UploadProgress.Visibility = Visibility.Visible;
            }
        }
    }
}
